@@ -24,6 +24,9 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
 #if defined(MEEGO_EDITION_HARMATTAN)
     viewer.setMainQmlFile(QLatin1String("qml/qalculette/mainN9.qml"));
     viewer.showFullScreen();
+#elif defined(Q_WS_MAEMO_5)
+    viewer.setMainQmlFile(QLatin1String("/opt/qalculette/qml/qalculette/main.qml"));
+    viewer.show();
 #else
     viewer.setMainQmlFile(QLatin1String("qml/qalculette/main.qml"));
     viewer.show();
